        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 22 <strong>control</strong><br>0,1,4,5,9,10,14,15,17,19,21,23,24,27,29,34,35,36,39,40,44,46';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 22 <br>2,3,7,8,11,12,16,18,20,22,26,28,31,32,33,37,38,42,43,45,49,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>6,13,25,30,41,47,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 22 <strong>control</strong><br>0,1,4,5,9,10,14,15,17,19,21,23,24,27,29,34,35,36,39,40,44,46';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 22 <br>2,3,7,8,11,12,16,18,20,22,26,28,31,32,33,37,38,42,43,45,49,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>6,13,25,30,41,47,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 22 <strong>control</strong><br>0,1,4,5,9,10,14,15,17,19,21,23,24,27,29,34,35,36,39,40,44,46';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 22 <br>2,3,7,8,11,12,16,18,20,22,26,28,31,32,33,37,38,42,43,45,49,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>6,13,25,30,41,47,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 22 <strong>control</strong><br>0,1,4,5,9,10,14,15,17,19,21,23,24,27,29,34,35,36,39,40,44,46';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 22 <br>2,3,7,8,11,12,16,18,20,22,26,28,31,32,33,37,38,42,43,45,49,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>6,13,25,30,41,47,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 22 <strong>control</strong><br>0,1,4,5,9,10,14,15,17,19,21,23,24,27,29,34,35,36,39,40,44,46';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 22 <br>2,3,7,8,11,12,16,18,20,22,26,28,31,32,33,37,38,42,43,45,49,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260622 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>6,13,25,30,41,47,48';}
}
